MonthViewKeys class abstract

A key holder of all MonthView keys

Annotations

Constructors

MonthViewKeys()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

events → Map<CalendarEvent, GlobalKey<State<StatefulWidget>>>
Map of keys for the displayed events (by event object)
final
layouts → Map<DateTime, GlobalKey<State<StatefulWidget>>>
Map of keys for the events layouts (by day date)
final
timeline ↔ Map<DateTime, GlobalKey<State<StatefulWidget>>>
A key for the timeline view
getter/setter pair