TimeScaleTheme class

Wrapper for the TimeScale view customization parameters

Constructors

TimeScaleTheme({double width = 56, double hourExtent = 100, TimeMarkTheme currentTimeMarkTheme = const TimeMarkTheme(length: 48, color: Colors.red), bool drawHalfHourMarks = true, TimeMarkTheme halfHourMarkTheme = const TimeMarkTheme(length: 16), bool drawQuarterHourMarks = true, TimeMarkTheme quarterHourMarkTheme = const TimeMarkTheme(length: 8), DateFormatter hourFormatter = _defaultHourFormatter, TextStyle? textStyle = const TextStyle(fontSize: 12, color: Colors.black), MarksAlign marksAlign = MarksAlign.left})
Customize the TimeScale with the parameters
const

Properties

currentTimeMarkTheme → TimeMarkTheme
Current time mark customization parameters
final
drawHalfHourMarks → bool
Whether a half of an hour mark is need to show
final
drawQuarterHourMarks → bool
Whether a quarter of an hour mark is need to show
final
halfHourMarkTheme → TimeMarkTheme
A half of an hour mark customization parameters
final
hashCode → int
The hash code for this object.
no setterinherited
hourExtent → double
Distance between two hours
final
hourFormatter → DateFormatter
Hour string formatter
final
marksAlign → MarksAlign
Scale marks alignment
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
quarterHourMarkTheme → TimeMarkTheme
A quarter of an hour mark customization parameters
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textStyle → TextStyle?
Hour text style
final
width → double
Width of the view (is needed to set a padding)
final

Methods

copyWith({double? width, double? hourExtent, TimeMarkTheme? currentTimeMarkTheme, bool? drawHalfHourMarks, TimeMarkTheme? halfHourMarkTheme, bool? drawQuarterHourMarks, TimeMarkTheme? quarterHourMarkTheme, DateFormatter? hourFormatter, TextStyle? textStyle, MarksAlign? marksAlign}) → TimeScaleTheme
Creates a copy of this theme but with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited